#!/usr/bin/env node
var fs = require('fs');
var util = require('util');
var postcss = require('postcss');
var colorsOnly = require('./');
var usage = 'Usage: css-color-extractor <inputFile> ' +
'<outputFile?> [-g|--without-grey] [-m|--without-monochrome]';
var argv = require('yargs')
  .usage(usage)
  .demand(1)
  .alias('g', 'without-grey')
  .alias('m', 'without-monochrome')
  .argv;

function error(e) {
  console.log(e.message || e);
  process.exit(1);
}

if (argv._.length === 0) {
  error('Input file is missing.');
}

var inputFile = argv._[0];

var outputFile = argv._.length > 1 ? argv._[1] : null;

fs.readFile(inputFile, 'utf8', function(err, data) {
  if (err) {
    error(err);
  }

  var processOpts = {
    from: inputFile,
  };

  if (outputFile) {
    processOpts.to = outputFile;
  }

  colorsOnlyOpts = {
    inputFile: inputFile,
    outputFile: outputFile,
    withoutGrey: argv.g,
    withoutMonochrome: argv.m
  };

  var result = postcss(colorsOnly(colorsOnlyOpts)).process(data, processOpts);

  if (!outputFile) {
    console.log(result.css);
  }
});
